@@ -1,10 +1,11 @@
 package Test::Mojo::Role::TestDeep;
 # ABSTRACT: Add Test::Deep methods to Test::Mojo::WithRoles
-$Test::Mojo::Role::TestDeep::VERSION = '0.006';
+$Test::Mojo::Role::TestDeep::VERSION = '0.007';
 
 use strict;
 use warnings;
 use Role::Tiny;
+use Test::More;
 use Test::Deep qw( cmp_deeply );
 
 
@@ -26,7 +27,9 @@ sub json_deeply {
     my $given = $t->tx->res->json( $ptr );
 
     local $Test::Builder::Level = $Test::Builder::Level + 1;
-    return $t->success( cmp_deeply( $given, $expect, $desc ) );
+    my $result = cmp_deeply( $given, $expect, $desc )
+        or diag "Got JSON: ", explain $given;
+    return $t->success( $result );
 }
 
 
@@ -35,7 +38,20 @@ sub text_deeply {
     $desc ||= qq{deeply match text for "$sel"};
     my @given = $t->tx->res->dom->find( $sel )->map( 'text' )->each;
     local $Test::Builder::Level = $Test::Builder::Level + 1;
-    return $t->success( cmp_deeply( \@given, $expect, $desc ) );
+    my $result = cmp_deeply( \@given, $expect, $desc )
+        or diag "Got text: \n", explain \@given;
+    return $t->success( $result );
+}
+
+
+sub all_text_deeply {
+    my ( $t, $sel, $expect, $desc ) = @_;
+    $desc ||= qq{deeply match all text for "$sel"};
+    my @given = $t->tx->res->dom->find( $sel )->map( 'all_text' )->each;
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+    my $result = cmp_deeply( \@given, $expect, $desc )
+        or diag "Got text: \n", explain \@given;
+    return $t->success( $result );
 }
 
 
@@ -56,7 +72,9 @@ sub attr_deeply {
     }
 
     local $Test::Builder::Level = $Test::Builder::Level + 1;
-    return $t->success( cmp_deeply( \%given, \%expect, $desc ) );
+    my $result = cmp_deeply( \%given, \%expect, $desc )
+        or diag "Got attrs: \n", explain \%given;
+    return $t->success( $result );
 }
 
 1;
@@ -71,7 +89,7 @@ Test::Mojo::Role::TestDeep - Add Test::Deep methods to Test::Mojo::WithRoles
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -165,6 +183,46 @@ This is equivalent to:
         bag( qw( Home Blog Projects ) ),
         'nav element text is correct';
 
+=head2 all_text_deeply
+
+    $t->all_text_deeply( $selector => $expect, $desc );
+
+Test the complete text of the elements and all child elements matched by
+the given C<$selector> against the given test. C<$expect> is a data
+structure containing L<Test::Deep comparisons|Test::Deep/SPECIAL
+COMPARISONS PROVIDED> to run. C<$desc> is an optional description of the
+test.
+
+The elements will always be an arrayref, even if only one
+element matches.
+
+For example:
+
+    # test.html
+    <nav>
+        <ul>
+            <li><a href="/"><em>Home</em></a></li>
+            <li><a href="/blog">Blog</a></li>
+            <li><a href="/projects"><strong>Projects</strong></a></li>
+        </ul>
+    </nav>
+
+    # test.t
+    $t->get_ok( 'test.html' )
+      ->all_text_deeply(
+        'nav a' => bag( qw( Home Blog Projects ) ),
+        'nav element text is correct',
+      );
+
+This is equivalent to:
+
+    $t->get_ok( 'test.html' );
+    my $dom = $t->tx->res->dom;
+    cmp_deeply
+        [ $dom->find( 'nav a' )->map( 'all_text' )->each ],
+        bag( qw( Home Blog Projects ) ),
+        'nav element text is correct';
+
 =head2 attr_deeply
 
     $t->attr_deeply( $selector, $attr => $expect, ..., $desc );
